aboutsummaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
authorAlon Zakai <alonzakai@gmail.com>2014-04-17 15:28:58 -0700
committerAlon Zakai <alonzakai@gmail.com>2014-04-17 15:28:58 -0700
commit326078dbfd2d1b412546dffef81964c3d2ca125d (patch)
treee0036cd004aea5667faad8049a1fc8fcdf68420d /tests
parentc584078d47008008102c0d580a8f97d928683331 (diff)
disable a failing test due to an llvm lto bug
Diffstat (limited to 'tests')
-rw-r--r--tests/test_core.py6
1 files changed, 4 insertions, 2 deletions
diff --git a/tests/test_core.py b/tests/test_core.py
index ab4897f8..1b116c4a 100644
--- a/tests/test_core.py
+++ b/tests/test_core.py
@@ -5272,8 +5272,10 @@ def process(filename):
if 'newfail' in name: continue
if os.environ.get('EMCC_FAST_COMPILER') == '0' and os.path.basename(name) in [
'18.cpp', '15.c'
- ]:
- continue # works only in fastcomp
+ ]: continue # works only in fastcomp
+ if x == 'lto' and self.run_name == 'default' and os.path.basename(name) in [
+ '19.c'
+ ]: continue # LLVM LTO bug
print name
self.do_run(open(path_from_root('tests', 'fuzz', name)).read(),